#!/bin/bash
##
# Capture final output from a terminal program, running within screen.
#
# Syntax:
#   capture.sh <input file> <output file> <width> <height> <command to capture>

# Get the input file
INPUT=$1
shift

# Expand the name to the current directory, if relevant
if [ "${INPUT:0:1}" != "/" ] ; then
    INPUT="$(pwd)/$INPUT"
fi

# Get the output file
OUTPUT=$1
shift

# Expand the name to the current directory, if relevant
if [ "${OUTPUT:0:1}" != "/" ] ; then
    OUTPUT="$(pwd)/$OUTPUT"
fi

# Get the width and height
WIDTH=$1
shift
HEIGHT=$1
shift

# Read the command and arguments
COMMAND=$@

# Sometimes we lose the first character, so wait a moment.
sleep 1

# Configure the screen size
echo -e -n \\033]83\;width -w $WIDTH $HEIGHT\\007
export COLUMNS=$WIDTH
export LINES=$HEIGHT

# Sometimes we lose the first character, so wait a moment.
sleep 1

# Clear the screen before we start
clear

# Run the command and remember the return code
$COMMAND < $INPUT
RC=$?

# Issue the 'screen' command to capture the output to a file
#echo COLS: $COLUMNS
#echo ROWS: $LINES
#sleep 1
/bin/echo -e -n \\033]83\;hardcopy \"$OUTPUT\"\\007

# Exit with the correct return code
exit $RC
